summaryrefslogtreecommitdiff
path: root/src/base_media_base.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/base_media_base.h')
-rw-r--r--src/base_media_base.h19
1 files changed, 18 insertions, 1 deletions
diff --git a/src/base_media_base.h b/src/base_media_base.h
index 74185c72b..b25661fa8 100644
--- a/src/base_media_base.h
+++ b/src/base_media_base.h
@@ -75,7 +75,7 @@ struct BaseSet {
};
/**
* Base for all base media (graphics, sound)
* @tparam Tbase_set the real set we're going to be
*/
template <class Tbase_set>
@@ -194,4 +194,21 @@ public:
static void DeterminePalette();
};
+/** All data of a sounds set. */
+struct SoundsSet : BaseSet<SoundsSet, 1> {
+ /**
+ * Is this set useable? Are enough files found to think it exists.
+ * @return true if it's useable.
+ */
+ bool IsUseable() const
+ {
+ return this->found_files > 0;
+ }
+};
+
+/** All data/functions related with replacing the base sounds */
+class BaseSounds : public BaseMedia<SoundsSet> {
+public:
+};
+
#endif /* BASE_MEDIA_BASE_H */
@@ -75,7 +75,7 @@ struct BaseSet {
};
/**
- * Base for all base media (graphics, sound)
+ * Base for all base media (graphics, sounds)
* @tparam Tbase_set the real set we're going to be
*/